You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by rh...@apache.org on 2006/04/25 15:35:42 UTC

svn commit: r396881 - in /db/derby/code/trunk: java/client/org/apache/derby/client/ java/client/org/apache/derby/client/am/ java/client/org/apache/derby/client/net/ java/client/org/apache/derby/jdbc/ java/tools/org/apache/derby/impl/tools/ij/ tools/jav...

Author: rhillegas
Date: Tue Apr 25 06:35:37 2006
New Revision: 396881

URL: http://svn.apache.org/viewcvs?rev=396881&view=rev
Log:
DERBY-1246: Commit derby-1246.diff, making the public network api conform to the inheritance pattern of the embedded api.

Added:
    db/derby/code/trunk/java/client/org/apache/derby/client/ClientXAConnection40.java   (with props)
    db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource40.java   (with props)
    db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource40.java   (with props)
Modified:
    db/derby/code/trunk/java/client/org/apache/derby/client/ClientDataSourceFactory.java
    db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection.java
    db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection40.java
    db/derby/code/trunk/java/client/org/apache/derby/client/am/ClientJDBCObjectFactory.java
    db/derby/code/trunk/java/client/org/apache/derby/client/am/Connection.java
    db/derby/code/trunk/java/client/org/apache/derby/client/am/LogWriter.java
    db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl.java
    db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl40.java
    db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection.java
    db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection40.java
    db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection.java
    db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection40.java
    db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource.java
    db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource.java
    db/derby/code/trunk/java/tools/org/apache/derby/impl/tools/ij/xaHelper.java
    db/derby/code/trunk/tools/javadoc/publishedapi_jdbc4.ant

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/ClientDataSourceFactory.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/ClientDataSourceFactory.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/ClientDataSourceFactory.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/ClientDataSourceFactory.java Tue Apr 25 06:35:37 2006
@@ -25,6 +25,7 @@
 
 import javax.naming.RefAddr;
 import javax.naming.Reference;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 
 import org.apache.derby.jdbc.ClientConnectionPoolDataSource;
 import org.apache.derby.jdbc.ClientDataSource;
@@ -79,7 +80,7 @@
         javax.naming.Reference ref = (javax.naming.Reference) refObj;
 
         // Create the proper data source object shell.
-        ClientDataSource ds = null;
+        ClientBaseDataSource ds = null;
         if (ref.getClassName().equals(ClientDataSource.className__)) {
             ds = new ClientDataSource();
         } else if (ref.getClassName().equals(ClientXADataSource.className__)) {

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection.java Tue Apr 25 06:35:37 2006
@@ -21,6 +21,7 @@
 
 import java.sql.SQLException;
 import org.apache.derby.client.net.NetXAConnection;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 import org.apache.derby.jdbc.ClientDataSource;
 import org.apache.derby.jdbc.ClientDriver;
 import org.apache.derby.client.am.MessageId;
@@ -43,14 +44,14 @@
     protected int rmId_ = 0;
 
     // Cached stuff from constructor
-    private ClientDataSource ds_;
+    private ClientBaseDataSource ds_;
     private String user_;
     private String password_;
 
     // Constructor for Non-XA pooled connections.
     // Using standard Java APIs, a CPDS is passed in.
     // user/password overrides anything on the ds.
-    public ClientPooledConnection(ClientDataSource ds,
+    public ClientPooledConnection(ClientBaseDataSource ds,
                                   org.apache.derby.client.am.LogWriter logWriter,
                                   String user,
                                   String password) throws SQLException {
@@ -82,7 +83,7 @@
     // Constructor for XA pooled connections only.
     // Using standard Java APIs, a CPDS is passed in.
     // user/password overrides anything on the ds.
-    public ClientPooledConnection(ClientDataSource ds,
+    public ClientPooledConnection(ClientBaseDataSource ds,
                                   org.apache.derby.client.am.LogWriter logWriter,
                                   String user,
                                   String password,
@@ -105,7 +106,7 @@
         }
     }
 
-    public ClientPooledConnection(ClientDataSource ds,
+    public ClientPooledConnection(ClientBaseDataSource ds,
                                   org.apache.derby.client.am.LogWriter logWriter) throws SQLException {
         logWriter_ = logWriter;
         ds_ = ds;
@@ -260,7 +261,7 @@
      * @param rmId 
      * @return NetXAConnection
      */
-    protected NetXAConnection getNetXAConnection (ClientDataSource ds,
+    protected NetXAConnection getNetXAConnection (ClientBaseDataSource ds,
                                   NetLogWriter logWriter,
                                   String user,
                                   String password,

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection40.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection40.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection40.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/ClientPooledConnection40.java Tue Apr 25 06:35:37 2006
@@ -22,6 +22,7 @@
 
 import java.sql.SQLException;
 import org.apache.derby.client.net.NetXAConnection;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 import org.apache.derby.jdbc.ClientDataSource;
 import javax.sql.StatementEventListener;
 import org.apache.derby.client.am.SqlException;
@@ -30,7 +31,7 @@
 
 public class ClientPooledConnection40 extends ClientPooledConnection {
     
-    public ClientPooledConnection40(ClientDataSource ds,
+    public ClientPooledConnection40(ClientBaseDataSource ds,
         org.apache.derby.client.am.LogWriter logWriter,
         String user,
         String password) throws SQLException {
@@ -39,7 +40,7 @@
     }
     
     
-    public ClientPooledConnection40(ClientDataSource ds,
+    public ClientPooledConnection40(ClientBaseDataSource ds,
         org.apache.derby.client.am.LogWriter logWriter,
         String user,
         String password,
@@ -48,7 +49,7 @@
         
     }
     
-    public ClientPooledConnection40(ClientDataSource ds,
+    public ClientPooledConnection40(ClientBaseDataSource ds,
         org.apache.derby.client.am.LogWriter logWriter) throws SQLException {
         super(ds,logWriter);
     }
@@ -70,7 +71,7 @@
      * @param rmId
      * @return NetXAConnection
      */
-    protected NetXAConnection getNetXAConnection (ClientDataSource ds,
+    protected NetXAConnection getNetXAConnection (ClientBaseDataSource ds,
                                   NetLogWriter logWriter,
                                   String user,
                                   String password,

Added: db/derby/code/trunk/java/client/org/apache/derby/client/ClientXAConnection40.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/ClientXAConnection40.java?rev=396881&view=auto
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/ClientXAConnection40.java (added)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/ClientXAConnection40.java Tue Apr 25 06:35:37 2006
@@ -0,0 +1,104 @@
+/*
+
+   Derby - Class org.apache.derby.client.ClientXAConnection40
+
+   Copyright (c) 2006 The Apache Software Foundation or its licensors, where applicable.
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+      http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+*/
+
+package org.apache.derby.client;
+
+import java.sql.SQLException;
+import javax.sql.StatementEventListener;
+import org.apache.derby.client.am.SqlException;
+import org.apache.derby.client.net.NetLogWriter;
+import org.apache.derby.client.net.NetXAConnection;
+import org.apache.derby.client.net.NetXAConnection40;
+import org.apache.derby.jdbc.ClientDataSource;
+import org.apache.derby.jdbc.ClientXADataSource;
+
+/**
+ * jdbc4.0 implementation of XAConnection
+ */ 
+public class ClientXAConnection40 extends ClientXAConnection {
+    
+    /**
+     * Constructor for ClientXAConnection40.
+     * @param ds 
+     * @param logWtr 
+     * @param userId 
+     * @param password 
+     */
+    public ClientXAConnection40 (ClientXADataSource ds,
+                              org.apache.derby.client.net.NetLogWriter logWtr,
+                              String userId,
+                              String password) throws SQLException {
+        super(ds, logWtr, userId, password);
+    }
+    
+    
+    /**
+     * Removes the specified <code>StatementEventListener</code> from the list of
+     * components that will be notified when the driver detects that a
+     * <code>PreparedStatement</code> has been closed or is invalid.
+     * <p>
+     *
+     * @param listener	the component which implements the
+     * <code>StatementEventListener</code> interface that was previously
+     * registered with this <code>PooledConnection</code> object
+     * <p>
+     */
+    public void removeStatementEventListener(StatementEventListener listener) {
+        throw new UnsupportedOperationException();
+    }
+    
+    /**
+     * Registers a <code>StatementEventListener</code> with this <code>PooledConnection</code> object.  Components that
+     * wish to be notified when  <code>PreparedStatement</code>s created by the
+     * connection are closed or are detected to be invalid may use this method
+     * to register a <code>StatementEventListener</code> with this <code>PooledConnection</code> object.
+     * <p>
+     *
+     * @param listener	an component which implements the 
+     *      <code>StatementEventListener</code> interface that is to be 
+     *      registered with this <code>PooledConnection</code> object
+     * <p>
+     */
+    public void addStatementEventListener(StatementEventListener listener) {
+        throw new UnsupportedOperationException();
+    }
+    
+        /**
+     * creates and returns NetXAConnection40.
+     * @param ds
+     * @param logWriter
+     * @param user
+     * @param password
+     * @param rmId
+     * @return NetXAConnection
+     */
+    protected NetXAConnection getNetXAConnection (ClientDataSource ds,
+                                  NetLogWriter logWriter,
+                                  String user,
+                                  String password,
+                                  int rmId) throws SqlException {
+        return new NetXAConnection40 (logWriter,
+                user,
+                password,
+                ds,
+                rmId,
+                true);
+    }    
+}

Propchange: db/derby/code/trunk/java/client/org/apache/derby/client/ClientXAConnection40.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/am/ClientJDBCObjectFactory.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/am/ClientJDBCObjectFactory.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/am/ClientJDBCObjectFactory.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/am/ClientJDBCObjectFactory.java Tue Apr 25 06:35:37 2006
@@ -20,11 +20,10 @@
 
 package org.apache.derby.client.am;
 
-import java.rmi.UnexpectedException;
 import org.apache.derby.client.ClientPooledConnection;
 import org.apache.derby.jdbc.ClientDataSource;
-import java.sql.Connection;
 import java.sql.SQLException;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 
 /**
  *
@@ -41,7 +40,7 @@
      * ClientPooledConnection (or ClientPooledConnection40) class which
      * implements javax.sql.PooledConnection
      */
-    ClientPooledConnection newClientPooledConnection(ClientDataSource ds,
+    ClientPooledConnection newClientPooledConnection(ClientBaseDataSource ds,
             LogWriter logWriter,String user,String password)
             throws SQLException;
     
@@ -50,7 +49,7 @@
      * ClientPooledConnection(or ClientPooledConnection40) class which
      * implements javax.sql.PooledConnection
      */
-    ClientPooledConnection newClientPooledConnection(ClientDataSource ds,
+    ClientPooledConnection newClientPooledConnection(ClientBaseDataSource ds,
             LogWriter logWriter,String user,String password,int rmId)
             throws SQLException;
     
@@ -97,7 +96,7 @@
      */
     org.apache.derby.client.am.Connection newNetConnection(
             LogWriter netLogWriter,
-            org.apache.derby.jdbc.ClientDataSource clientDataSource,String user,
+            org.apache.derby.jdbc.ClientBaseDataSource clientDataSource,String user,
             String password) throws SqlException;
     
     /**
@@ -119,7 +118,7 @@
     org.apache.derby.client.am.Connection newNetConnection(
             LogWriter netLogWriter,
             String user,String password,
-            org.apache.derby.jdbc.ClientDataSource dataSource,int rmId,
+            org.apache.derby.jdbc.ClientBaseDataSource dataSource,int rmId,
             boolean isXAConn) throws SqlException;
     
     /**
@@ -130,7 +129,7 @@
      */
     org.apache.derby.client.am.Connection newNetConnection(
             LogWriter netLogWriter,String ipaddr,
-            int portNumber,org.apache.derby.jdbc.ClientDataSource dataSource,
+            int portNumber,org.apache.derby.jdbc.ClientBaseDataSource dataSource,
             boolean isXAConn) throws SqlException;
     
     /**

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/am/Connection.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/am/Connection.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/am/Connection.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/am/Connection.java Tue Apr 25 06:35:37 2006
@@ -20,6 +20,7 @@
 
 package org.apache.derby.client.am;
 
+import org.apache.derby.jdbc.ClientBaseDataSource;
 import org.apache.derby.jdbc.ClientDataSource;
 import org.apache.derby.shared.common.reference.JDBC30Translation;
 import org.apache.derby.shared.common.reference.SQLState;
@@ -127,7 +128,7 @@
     public int xaHostVersion_ = 0;
 
     public int loginTimeout_;
-    public org.apache.derby.jdbc.ClientDataSource dataSource_;
+    public org.apache.derby.jdbc.ClientBaseDataSource dataSource_;
     public String serverNameIP_;
     public int portNumber_;
 
@@ -144,7 +145,8 @@
     protected Connection(org.apache.derby.client.am.LogWriter logWriter,
                          String user,
                          String password,
-                         org.apache.derby.jdbc.ClientDataSource dataSource) throws SqlException {
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource) 
+                                                           throws SqlException {
         initConnection(logWriter, user, dataSource);
     }
 
@@ -152,7 +154,8 @@
                          String user,
                          String password,
                          boolean isXAConn,
-                         org.apache.derby.jdbc.ClientDataSource dataSource) throws SqlException {
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource) 
+                                                           throws SqlException {
         isXAConnection_ = isXAConn;
         initConnection(logWriter, user, dataSource);
     }
@@ -160,7 +163,8 @@
     // For jdbc 2 connections
     protected void initConnection(org.apache.derby.client.am.LogWriter logWriter,
                                   String user,
-                                  org.apache.derby.jdbc.ClientDataSource dataSource) throws SqlException {
+                                  org.apache.derby.jdbc.ClientBaseDataSource
+                                            dataSource) throws SqlException {
         if (logWriter != null) {
             logWriter.traceConnectEntry(dataSource);
         }
@@ -193,7 +197,8 @@
     // For jdbc 2 connections
     protected Connection(org.apache.derby.client.am.LogWriter logWriter,
                          boolean isXAConn,
-                         org.apache.derby.jdbc.ClientDataSource dataSource) throws SqlException {
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource) 
+                                                            throws SqlException {
         if (logWriter != null) {
             logWriter.traceConnectEntry(dataSource);
         }
@@ -222,7 +227,7 @@
     // This is a callback method, called by subsystem - NetConnection
     protected void resetConnection(LogWriter logWriter,
                                    String user,
-                                   ClientDataSource ds,
+                                   ClientBaseDataSource ds,
                                    boolean recomputeFromDataSource) throws SqlException {
         // clearWarningsX() will re-initialize the following properties
         clearWarningsX();
@@ -1813,9 +1818,12 @@
     // can this be called in a unit of work
     // can this be called from within a stored procedure
     //
-    synchronized public void reset(LogWriter logWriter, String user, String password, ClientDataSource ds, boolean recomputeFromDataSource) throws SqlException {
+    synchronized public void reset(LogWriter logWriter, String user, 
+            String password, ClientBaseDataSource ds, 
+            boolean recomputeFromDataSource) throws SqlException {
         if (logWriter != null) {
-            logWriter.traceConnectResetEntry(this, logWriter, user, (ds != null) ? ds : dataSource_);
+            logWriter.traceConnectResetEntry(this, logWriter, user, 
+                                            (ds != null) ? ds : dataSource_);
         }
         try {
             reset_(logWriter, user, password, ds, recomputeFromDataSource);
@@ -1827,7 +1835,8 @@
         }
     }
 
-    synchronized public void reset(LogWriter logWriter, ClientDataSource ds, boolean recomputeFromDataSource) throws SqlException {
+    synchronized public void reset(LogWriter logWriter, ClientBaseDataSource ds, 
+            boolean recomputeFromDataSource) throws SqlException {
         if (logWriter != null) {
             logWriter.traceConnectResetEntry(this, logWriter, null, (ds != null) ? ds : dataSource_);
         }
@@ -1849,9 +1858,13 @@
         availableForReuse_ = false;
     }
 
-    abstract protected void reset_(LogWriter logWriter, String user, String password, ClientDataSource ds, boolean recomputerFromDataSource) throws SqlException;
-
-    abstract protected void reset_(LogWriter logWriter, ClientDataSource ds, boolean recomputerFromDataSource) throws SqlException;
+    abstract protected void reset_(LogWriter logWriter, String user, 
+            String password, ClientBaseDataSource ds, 
+            boolean recomputerFromDataSource) throws SqlException;
+
+    abstract protected void reset_(LogWriter logWriter, 
+            ClientBaseDataSource ds, 
+            boolean recomputerFromDataSource) throws SqlException;
 
     protected void completeReset(boolean isDeferredReset, boolean recomputeFromDataSource) throws SqlException {
         open_ = true;

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/am/LogWriter.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/am/LogWriter.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl.java Tue Apr 25 06:35:37 2006
@@ -35,8 +35,8 @@
 import org.apache.derby.client.am.Statement;
 import org.apache.derby.client.am.SqlException;
 import org.apache.derby.client.am.Cursor;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 import org.apache.derby.client.am.ColumnMetaData;
-import org.apache.derby.jdbc.ClientDataSource;
 
 /**
  * Implements the the ClientJDBCObjectFactory interface and returns the classes
@@ -49,7 +49,7 @@
     /**
      * Returns an instance of org.apache.derby.client.ClientPooledConnection 
      */
-    public ClientPooledConnection newClientPooledConnection(ClientDataSource ds,
+    public ClientPooledConnection newClientPooledConnection(ClientBaseDataSource ds,
             LogWriter logWriter,String user,
             String password) throws SQLException {
         return new ClientPooledConnection(ds,logWriter,user,password);
@@ -57,7 +57,7 @@
     /**
      * Returns an instance of org.apache.derby.client.ClientPooledConnection 
      */
-    public ClientPooledConnection newClientPooledConnection(ClientDataSource ds,
+    public ClientPooledConnection newClientPooledConnection(ClientBaseDataSource ds,
             LogWriter logWriter,String user,
             String password,int rmId) throws SQLException {
         return new ClientPooledConnection(ds,logWriter,user,password,rmId);
@@ -107,7 +107,7 @@
      */
     public org.apache.derby.client.am.Connection newNetConnection(
             org.apache.derby.client.am.LogWriter netLogWriter,
-            org.apache.derby.jdbc.ClientDataSource clientDataSource,
+            org.apache.derby.jdbc.ClientBaseDataSource clientDataSource,
             String user,String password) throws SqlException {
         return  (org.apache.derby.client.am.Connection)
         (new NetConnection((NetLogWriter)netLogWriter,clientDataSource
@@ -131,7 +131,7 @@
     public org.apache.derby.client.am.Connection newNetConnection(
             org.apache.derby.client.am.LogWriter netLogWriter,String user,
             String password,
-            org.apache.derby.jdbc.ClientDataSource dataSource,
+            org.apache.derby.jdbc.ClientBaseDataSource dataSource,
             int rmId,boolean isXAConn) throws SqlException {
         return (org.apache.derby.client.am.Connection)
         (new NetConnection((NetLogWriter)netLogWriter,user,password,dataSource,rmId,
@@ -143,7 +143,7 @@
     public org.apache.derby.client.am.Connection newNetConnection(
             org.apache.derby.client.am.LogWriter netLogWriter,
             String ipaddr,int portNumber,
-            org.apache.derby.jdbc.ClientDataSource dataSource,
+            org.apache.derby.jdbc.ClientBaseDataSource dataSource,
             boolean isXAConn) throws SqlException {
         return (org.apache.derby.client.am.Connection)
         new NetConnection((NetLogWriter)netLogWriter,ipaddr,portNumber,dataSource,

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl40.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl40.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl40.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl40.java Tue Apr 25 06:35:37 2006
@@ -41,6 +41,7 @@
 import org.apache.derby.client.am.Cursor;
 import org.apache.derby.jdbc.ClientDataSource;
 import java.sql.SQLException;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 
 /**
  * Implements the ClientJDBCObjectFactory interface
@@ -58,16 +59,16 @@
     /**
      * Returns an instance of org.apache.derby.client.ClientPooledConnection40 
      */
-    public ClientPooledConnection newClientPooledConnection(ClientDataSource ds,
-            LogWriter logWriter,String user,
+    public ClientPooledConnection newClientPooledConnection(
+            ClientBaseDataSource ds, LogWriter logWriter,String user,
             String password) throws SQLException {
         return new ClientPooledConnection40(ds,logWriter,user,password);
     }
     /**
      * Returns an instance of org.apache.derby.client.ClientPooledConnection40 
      */
-    public ClientPooledConnection newClientPooledConnection(ClientDataSource ds,
-            LogWriter logWriter,String user,
+    public ClientPooledConnection newClientPooledConnection(
+            ClientBaseDataSource ds, LogWriter logWriter,String user,
             String password,int rmId) throws SQLException {
         return new ClientPooledConnection40(ds,logWriter,user,password,rmId);
     }
@@ -116,7 +117,7 @@
      */
     public org.apache.derby.client.am.Connection newNetConnection
             (org.apache.derby.client.am.LogWriter netLogWriter,
-            org.apache.derby.jdbc.ClientDataSource clientDataSource,
+            org.apache.derby.jdbc.ClientBaseDataSource clientDataSource,
             String user,String password) throws SqlException {
         return (org.apache.derby.client.am.Connection)
         (new NetConnection40((NetLogWriter)netLogWriter,clientDataSource,user,password));
@@ -140,7 +141,7 @@
             newNetConnection(org.apache.derby.client.am.LogWriter netLogWriter,
             String user,
             String password,
-            org.apache.derby.jdbc.ClientDataSource dataSource,
+            org.apache.derby.jdbc.ClientBaseDataSource dataSource,
             int rmId,boolean isXAConn) throws SqlException {
         return (org.apache.derby.client.am.Connection)
         (new NetConnection40((NetLogWriter)netLogWriter,user,password,dataSource,
@@ -152,7 +153,7 @@
     public org.apache.derby.client.am.Connection
             newNetConnection(org.apache.derby.client.am.LogWriter netLogWriter,
             String ipaddr,int portNumber,
-            org.apache.derby.jdbc.ClientDataSource dataSource,
+            org.apache.derby.jdbc.ClientBaseDataSource dataSource,
             boolean isXAConn) throws SqlException {
         return (org.apache.derby.client.am.Connection)
         (new NetConnection40((NetLogWriter)netLogWriter,ipaddr,portNumber,dataSource,

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection.java Tue Apr 25 06:35:37 2006
@@ -29,6 +29,7 @@
 import org.apache.derby.client.am.SqlException;
 import org.apache.derby.client.am.Statement;
 import org.apache.derby.client.am.Utils;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 import org.apache.derby.jdbc.ClientDataSource;
 import org.apache.derby.jdbc.ClientDriver;
 
@@ -171,7 +172,7 @@
     }
 
     public NetConnection(NetLogWriter netLogWriter,
-                         org.apache.derby.jdbc.ClientDataSource dataSource,
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                          String user,
                          String password) throws SqlException {
         super(netLogWriter, user, password, dataSource);
@@ -191,8 +192,8 @@
             throw netAgent_.exceptionOpeningSocket_;
         }
         checkDatabaseName();
-        String password = ClientDataSource.getPassword(properties);
-        securityMechanism_ = ClientDataSource.getSecurityMechanism(properties);
+        String password = ClientBaseDataSource.getPassword(properties);
+        securityMechanism_ = ClientBaseDataSource.getSecurityMechanism(properties);
         flowConnect(password, securityMechanism_);
         if(!isConnectionNull())
         	completeConnect();
@@ -202,7 +203,7 @@
     public NetConnection(NetLogWriter netLogWriter,
                          String user,
                          String password,
-                         org.apache.derby.jdbc.ClientDataSource dataSource,
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                          int rmId,
                          boolean isXAConn) throws SqlException {
         super(netLogWriter, user, password, isXAConn, dataSource);
@@ -213,7 +214,7 @@
     public NetConnection(NetLogWriter netLogWriter,
                          String ipaddr,
                          int portNumber,
-                         org.apache.derby.jdbc.ClientDataSource dataSource,
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                          boolean isXAConn) throws SqlException {
         super(netLogWriter, isXAConn, dataSource);
         netAgent_ = (NetAgent) super.agent_;
@@ -229,7 +230,7 @@
 
     private void initialize(String user,
                             String password,
-                            org.apache.derby.jdbc.ClientDataSource dataSource,
+                            org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                             int rmId,
                             boolean isXAConn) throws SqlException {
         securityMechanism_ = dataSource.getSecurityMechanism(password);
@@ -249,7 +250,7 @@
     public void resetNetConnection(org.apache.derby.client.am.LogWriter logWriter,
                                    String user,
                                    String password,
-                                   org.apache.derby.jdbc.ClientDataSource ds,
+                                   org.apache.derby.jdbc.ClientBaseDataSource ds,
                                    boolean recomputeFromDataSource) throws SqlException {
         super.resetConnection(logWriter, user, ds, recomputeFromDataSource);
         //----------------------------------------------------
@@ -285,22 +286,22 @@
 
     protected void reset_(org.apache.derby.client.am.LogWriter logWriter,
                           String user, String password,
-                          ClientDataSource ds,
+                          ClientBaseDataSource ds,
                           boolean recomputeFromDataSource) throws SqlException {
         checkResetPreconditions(logWriter, user, password, ds);
         resetNetConnection(logWriter, user, password, ds, recomputeFromDataSource);
     }
 
     protected void reset_(org.apache.derby.client.am.LogWriter logWriter,
-                          ClientDataSource ds,
+                          ClientBaseDataSource ds,
                           boolean recomputeFromDataSource) throws SqlException {
         checkResetPreconditions(logWriter, null, null, ds);
         resetNetConnection(logWriter, ds, recomputeFromDataSource);
     }
 
     private void resetNetConnection(org.apache.derby.client.am.LogWriter logWriter,
-                                    org.apache.derby.jdbc.ClientDataSource ds,
-                                    boolean recomputeFromDataSource) throws SqlException {
+                            org.apache.derby.jdbc.ClientBaseDataSource ds,
+                            boolean recomputeFromDataSource) throws SqlException {
         super.resetConnection(logWriter, null, ds, recomputeFromDataSource);
         //----------------------------------------------------
         if (recomputeFromDataSource) {
@@ -329,7 +330,7 @@
     protected void checkResetPreconditions(org.apache.derby.client.am.LogWriter logWriter,
                                            String user,
                                            String password,
-                                           ClientDataSource ds) throws SqlException {
+                                           ClientBaseDataSource ds) throws SqlException {
         if (inUnitOfWork_) {
             throw new SqlException(logWriter, "Connection reset is not allowed when inside a unit of work.");
         }

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection40.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection40.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection40.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/net/NetConnection40.java Tue Apr 25 06:35:37 2006
@@ -58,7 +58,7 @@
 	super(netLogWriter,databaseName,properties);
     }
     public NetConnection40(NetLogWriter netLogWriter,
-                         org.apache.derby.jdbc.ClientDataSource dataSource,
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                          String user,
                          String password) throws SqlException {
 	super(netLogWriter,dataSource,user,password);
@@ -74,7 +74,7 @@
      public NetConnection40(NetLogWriter netLogWriter,
                          String user,
                          String password,
-                         org.apache.derby.jdbc.ClientDataSource dataSource,
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                          int rmId,
                          boolean isXAConn) throws SqlException{
 	super(netLogWriter,user,password,dataSource,rmId,isXAConn);
@@ -82,7 +82,7 @@
     public NetConnection40(NetLogWriter netLogWriter,
                          String ipaddr,
                          int portNumber,
-                         org.apache.derby.jdbc.ClientDataSource dataSource,
+                         org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                          boolean isXAConn) throws SqlException{
         super(netLogWriter,ipaddr,portNumber,dataSource,isXAConn);
     }

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection.java Tue Apr 25 06:35:37 2006
@@ -37,7 +37,7 @@
     public NetXAConnection(NetLogWriter netLogWriter,
                            String user,
                            String password,
-                           org.apache.derby.jdbc.ClientDataSource dataSource,
+                           org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                            int rmId,
                            boolean isXAConn) throws SqlException {
         netCon = createNetConnection (netLogWriter, user, password, 
@@ -225,7 +225,7 @@
     protected NetConnection createNetConnection (NetLogWriter netLogWriter,
                            String user,
                            String password,
-                           org.apache.derby.jdbc.ClientDataSource dataSource,
+                           org.apache.derby.jdbc.ClientBaseDataSource dataSource,
                            int rmId,
                            boolean isXAConn) throws SqlException {        
         return new NetConnection (netLogWriter, user, password, 

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection40.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection40.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection40.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/net/NetXAConnection40.java Tue Apr 25 06:35:37 2006
@@ -32,7 +32,7 @@
     public NetXAConnection40(NetLogWriter netLogWriter,
             String user,
             String password,
-            org.apache.derby.jdbc.ClientDataSource dataSource,
+            org.apache.derby.jdbc.ClientBaseDataSource dataSource,
             int rmId,
             boolean isXAConn) throws SqlException {
         super(netLogWriter, user, password,

Modified: db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource.java Tue Apr 25 06:35:37 2006
@@ -22,9 +22,8 @@
 
 import java.sql.SQLException;
 import javax.sql.ConnectionPoolDataSource;
+import javax.sql.DataSource;
 import javax.sql.PooledConnection;
-
-import org.apache.derby.client.ClientPooledConnection;
 import org.apache.derby.client.am.LogWriter;
 import org.apache.derby.client.am.SqlException;
 
@@ -32,7 +31,8 @@
  * ClientConnectionPoolDataSource is a factory for PooledConnection objects. An object that implements this interface
  * will typically be registered with a naming service that is based on the Java Naming and Directory Interface (JNDI).
  */
-public class ClientConnectionPoolDataSource extends ClientDataSource implements ConnectionPoolDataSource {
+public class ClientConnectionPoolDataSource extends ClientBaseDataSource 
+                                           implements ConnectionPoolDataSource {
     private static final long serialVersionUID = -539234282156481377L;
     public static final String className__ = "org.apache.derby.jdbc.ClientConnectionPoolDataSource";
 
@@ -84,8 +84,10 @@
 
     //  method that establishes the initial physical connection
     // using DS properties instead of CPDS properties.
-    private PooledConnection getPooledConnectionX(LogWriter dncLogWriter, ClientDataSource ds, String user, String password) throws SQLException {
+    private PooledConnection getPooledConnectionX(LogWriter dncLogWriter, 
+                        ClientBaseDataSource ds, String user, 
+                        String password) throws SQLException {
             return ClientDriver.getFactory().newClientPooledConnection(ds,
                     dncLogWriter, user, password);
-    }
+    }   
 }

Added: db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource40.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource40.java?rev=396881&view=auto
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource40.java (added)
+++ db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource40.java Tue Apr 25 06:35:37 2006
@@ -0,0 +1,46 @@
+/*
+
+   Derby - Class org.apache.derby.jdbc.ClientConnectionPoolDataSource40
+
+   Copyright (c) 2006 The Apache Software Foundation or its licensors, where applicable.
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+      http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+*/
+
+package org.apache.derby.jdbc;
+
+import java.sql.BaseQuery;
+import java.sql.QueryObjectGenerator;
+import java.sql.SQLException;
+import javax.sql.ConnectionPoolDataSource;
+import org.apache.derby.client.am.SQLExceptionFactory;
+
+/**
+ * ConnectionPoolDataSource for jdbc4.0
+ */
+public class ClientConnectionPoolDataSource40
+        extends ClientConnectionPoolDataSource {
+    /**
+     * Retrieves the QueryObjectGenerator for the given JDBC driver.  If the
+     * JDBC driver does not provide its own QueryObjectGenerator, NULL is
+     * returned.
+     *
+     * @return The QueryObjectGenerator for this JDBC Driver or NULL if the 
+     * driver does not provide its own implementation
+     * @exception SQLException if a database access error occurs
+     */
+    public QueryObjectGenerator getQueryObjectGenerator() throws SQLException {
+        return null;
+    }    
+}

Propchange: db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientConnectionPoolDataSource40.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource.java Tue Apr 25 06:35:37 2006
@@ -21,6 +21,7 @@
 package org.apache.derby.jdbc;
 
 import java.sql.SQLException;
+import javax.sql.DataSource;
 import javax.sql.XAConnection;
 import javax.sql.XADataSource;
 
@@ -29,7 +30,7 @@
 import org.apache.derby.client.am.SqlException;
 
 
-public class ClientXADataSource extends ClientDataSource implements XADataSource {
+public class ClientXADataSource extends ClientBaseDataSource implements XADataSource {
     public static final String className__ = "org.apache.derby.jdbc.ClientXADataSource";
 
     // following serialVersionUID was generated by the JDK's serialver program
@@ -53,5 +54,5 @@
         {
             throw se.getSQLException();
         }
-    }
+    }    
 }

Added: db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource40.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource40.java?rev=396881&view=auto
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource40.java (added)
+++ db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource40.java Tue Apr 25 06:35:37 2006
@@ -0,0 +1,65 @@
+/*
+
+   Derby - Class org.apache.derby.jdbc.ClientXADataSource40
+
+   Copyright (c) 2006 The Apache Software Foundation or its licensors, where applicable.
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+      http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+*/
+
+package org.apache.derby.jdbc;
+
+import java.sql.BaseQuery;
+import java.sql.QueryObjectGenerator;
+import java.sql.SQLException;
+import javax.sql.DataSource;
+import javax.sql.XAConnection;
+import org.apache.derby.client.ClientXAConnection40;
+import org.apache.derby.client.am.SQLExceptionFactory;
+import org.apache.derby.client.am.SqlException;
+import org.apache.derby.client.net.NetLogWriter;
+
+/**
+ * XADataSource for jdbc4.0
+ */
+public class ClientXADataSource40 extends ClientXADataSource {
+    /**
+     * Retrieves the QueryObjectGenerator for the given JDBC driver.  If the
+     * JDBC driver does not provide its own QueryObjectGenerator, NULL is
+     * returned.
+     *
+     * @return The QueryObjectGenerator for this JDBC Driver or NULL if the
+     * driver does not provide its own implementation
+     * @exception SQLException if a database access error occurs
+     */
+    public QueryObjectGenerator getQueryObjectGenerator() throws SQLException {
+        return null;
+    }
+    
+    /**
+     * creates a jdbc4.0 XAConnection
+     * @param user 
+     * @param password 
+     * @return XAConnection
+     */
+    public XAConnection getXAConnection(String user, String password) throws SQLException {
+        try {
+            NetLogWriter dncLogWriter = (NetLogWriter) 
+                        super.computeDncLogWriterForNewConnection("_xads");
+            return new ClientXAConnection40 (this, dncLogWriter, user, password);
+        } catch ( SqlException se ) {
+            throw se.getSQLException();
+        }
+    }    
+}

Propchange: db/derby/code/trunk/java/client/org/apache/derby/jdbc/ClientXADataSource40.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: db/derby/code/trunk/java/tools/org/apache/derby/impl/tools/ij/xaHelper.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/tools/org/apache/derby/impl/tools/ij/xaHelper.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/java/tools/org/apache/derby/impl/tools/ij/xaHelper.java (original)
+++ db/derby/code/trunk/java/tools/org/apache/derby/impl/tools/ij/xaHelper.java Tue Apr 25 06:35:37 2006
@@ -501,9 +501,24 @@
 			if (isJCC)
 				return (XADataSource) 
 					(Class.forName("com.ibm.db2.jcc.DB2XADataSource").newInstance());
-			else if (isNetClient)
-				return (XADataSource) 
-					(Class.forName("org.apache.derby.jdbc.ClientXADataSource").newInstance());
+			else if (isNetClient){
+                            if (JVMInfo.JDK_ID >= JVMInfo.J2SE_16) {
+                                //running under jdk1.6 or higher 
+                                // try instantiating EmbeddedXADataSource40
+                                try {
+                                    return (XADataSource)(Class.forName(
+                                        "org.apache.derby.jdbc." +
+                                        "ClientXADataSource40").newInstance());                                        
+                                }
+                                catch (ClassNotFoundException e) {
+                                    //probably it was not compiled with jdbc4.0
+                                    //support go ahead with EmbeddedXADataSource
+                                }
+                            }
+                            return (XADataSource) (Class.forName(
+                                    "org.apache.derby.jdbc.ClientXADataSource"
+                                    ).newInstance());
+                        }
 			else {
                             if (JVMInfo.JDK_ID >= JVMInfo.J2SE_16) {
                                 //running under jdk1.6 or higher 

Modified: db/derby/code/trunk/tools/javadoc/publishedapi_jdbc4.ant
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/tools/javadoc/publishedapi_jdbc4.ant?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================
--- db/derby/code/trunk/tools/javadoc/publishedapi_jdbc4.ant (original)
+++ db/derby/code/trunk/tools/javadoc/publishedapi_jdbc4.ant Tue Apr 25 06:35:37 2006
@@ -17,7 +17,9 @@
 
 # package: org.apache.derby.jdbc
 
+org/apache/derby/jdbc/ClientConnectionPoolDataSource40.java
 org/apache/derby/jdbc/ClientDataSource40.java
+org/apache/derby/jdbc/ClientXADataSource40.java
 org/apache/derby/jdbc/EmbeddedConnectionPoolDataSource40.java
 org/apache/derby/jdbc/EmbeddedDataSource40.java
 org/apache/derby/jdbc/EmbeddedXADataSource40.java
--- db/derby/code/trunk/java/client/org/apache/derby/client/am/LogWriter.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/am/LogWriter.java Tue Apr 25 06:35:37 2006
@@ -27,6 +27,7 @@
 import javax.naming.NamingException;
 import javax.naming.RefAddr;
 import javax.naming.Reference;
+import org.apache.derby.jdbc.ClientBaseDataSource;
 
 import org.apache.derby.jdbc.ClientDataSource;
 import org.apache.derby.shared.common.reference.Attribute;
@@ -986,7 +987,7 @@
     // Including protocol manager levels, and driver configuration
 
     // Jdbc 2
-    public void traceConnectEntry(ClientDataSource dataSource) {
+    public void traceConnectEntry(ClientBaseDataSource dataSource) {
         if (traceSuspended()) {
             return;
         }
@@ -1014,7 +1015,8 @@
         }
     }
 
-    public void traceConnectResetEntry(Object instance, LogWriter logWriter, String user, ClientDataSource ds) {
+    public void traceConnectResetEntry(Object instance, LogWriter logWriter, 
+                                        String user, ClientBaseDataSource ds) {
         if (traceSuspended()) {
             return;
         }
@@ -1045,7 +1047,7 @@
 
     // ---------------------- tracing connects -----------------------------------
 
-    private void traceConnectsResetEntry(ClientDataSource dataSource) {
+    private void traceConnectsResetEntry(ClientBaseDataSource dataSource) {
         try {
             if (traceSuspended()) {
                 return;
@@ -1059,7 +1061,7 @@
         }
     }
 
-    private void traceConnectsEntry(ClientDataSource dataSource) {
+    private void traceConnectsEntry(ClientBaseDataSource dataSource) {
         try {
             if (traceSuspended()) {
                 return;
@@ -1223,9 +1225,9 @@
     }
     
     /**
      * Obtain a set of Properties for the ClientDataSource
      */
-    private Properties getProperties(ClientDataSource cds)
+    private Properties getProperties(ClientBaseDataSource cds)
     throws SqlException {
         
         Properties properties = new Properties();
@@ -1223,9 +1225,9 @@
     
     /**
-     * Obtain a set of Properties for the ClientDataSource
+     * Obtain a set of Properties for the ClientBaseDataSource
      */

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl.java
URL: http://svn.apache.org/viewcvs/db/derby/code/trunk/java/client/org/apache/derby/client/net/ClientJDBCObjectFactoryImpl.java?rev=396881&r1=396880&r2=396881&view=diff
==============================================================================